@@ -1,8 +1,14 @@
 # -*- coding: utf-8 -*-
-from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse, reverse_lazy
+from django.forms import ValidationError
 from django.http import HttpResponseRedirect
 from django.shortcuts import render_to_response, get_object_or_404, redirect
 from django.template import RequestContext
+from django.utils.translation import ugettext_lazy as _
+from django.views.generic import ListView
+from django.views.generic.detail import SingleObjectMixin
+from django.views.generic.edit import CreateView, DeleteView
+from django.http import Http404
 
 from planet.models import Blog, Feed, Author, Post
 from planet.forms import SearchForm
@@ -92,8 +98,8 @@ def author_detail(request, author_id, tag=None, slug=None):
 
 
 def posts_list(request):
-    posts = Post.site_objects.all().select_related("feed", "blog", "authors")\
-        .order_by("-date_modified")
+    posts = Post.site_objects.all().select_related("feed", "feed__blog")\
+        .prefetch_related("authors").order_by("-date_modified")
 
     return render_to_response("planet/posts/list.html", {"posts": posts},
         context_instance=RequestContext(request))
@@ -101,7 +107,9 @@ def posts_list(request):
 
 def post_detail(request, post_id, slug=None):
     post = get_object_or_404(
-        Post.objects.select_related("feed", "authors", "blog"), pk=post_id)
+        Post.objects.select_related("feed", "feed__blog").prefetch_related("authors"),
+        pk=post_id
+    )
 
     if not slug:
         return redirect(post, permanent=True)
@@ -161,14 +169,14 @@ def foaf(request):
     feeds = Feed.site_objects.all().select_related("blog")
 
     return render_to_response("planet/microformats/foaf.xml", {"feeds": feeds},
-        context_instance=RequestContext(request), mimetype="text/xml")
+        context_instance=RequestContext(request), content_type="text/xml")
 
 
 def opml(request):
     feeds = Feed.site_objects.all().select_related("blog")
 
     return render_to_response("planet/microformats/opml.xml", {"feeds": feeds},
-        context_instance=RequestContext(request), mimetype="text/xml")
+        context_instance=RequestContext(request), content_type="text/xml")
 
 
 def search(request):
@@ -235,3 +243,63 @@ def search(request):
 
     else:
         return HttpResponseRedirect(reverse("planet_post_list"))
+
+
+class FeedAddView(CreateView):
+    model = Feed
+    fields = ["url"]
+    template_name = 'planet/feeds/add.html'
+    success_message = _("Feed with url=%(url)s was created successfully")
+
+    def clean_url(self):
+        url = self.cleaned_data['url']
+
+        if Feed.objects.filter(url=url).count() > 0:
+            raise ValidationError(_('A feed with this URL already exists.'))
+
+        return url
+
+    def form_valid(self, form):
+        feed = form.save()
+
+        if self.request.user.is_authenticated():
+            feed.blog.owner = self.request.user
+            feed.blog.save()
+
+        self.object = feed
+
+        return HttpResponseRedirect(reverse("planet_index"))
+
+
+class BlogListByUserView(ListView):
+    template_name = 'planet/blogs/list_by_user.html'
+    model = Blog
+
+    def get_queryset(self):
+        return Blog.objects.filter(owner=self.request.user)
+
+
+class OwnedObjectMixin(SingleObjectMixin):
+    """
+    An object that needs to verify current user ownership
+    before allowing manipulation.
+
+    From https://github.com/PyAr/pyarweb/blob/b4095c5c1b474a207e45918683de400974f6a739/community/views.py#L43
+    """
+
+    def get_object(self, *args, **kwargs):
+        obj = super(OwnedObjectMixin, self).get_object(*args, **kwargs)
+
+        try:
+            if not obj.owner == self.request.user:
+                raise Http404()
+        except AttributeError:
+            pass
+
+        return obj
+
+
+class BlogDeleteView(DeleteView, OwnedObjectMixin):
+    template_name = 'planet/blogs/confirm_delete.html'
+    model = Blog
+    success_url = reverse_lazy('planet_blog_list_by_user')
